==> python-cupy-13.6.0-5-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/cupyx/scipy/signal/__init__.py <==
from cupyx.scipy.signal._signaltools import convolve  # NOQA
from cupyx.scipy.signal._signaltools import correlate  # NOQA
from cupyx.scipy.signal._signaltools import deconvolve  # NOQA
from cupyx.scipy.signal._signaltools import fftconvolve  # NOQA
from cupyx.scipy.signal._signaltools import choose_conv_method  # NOQA
from cupyx.scipy.signal._signaltools import oaconvolve  # NOQA
from cupyx.scipy.signal._signaltools import convolve2d  # NOQA
from cupyx.scipy.signal._signaltools import correlate2d  # NOQA
from cupyx.scipy.signal._signaltools import correlation_lags  # NOQA
from cupyx.scipy.signal._signaltools import wiener  # NOQA
from cupyx.scipy.signal._signaltools import order_filter  # NOQA
from cupyx.scipy.signal._signaltools import medfilt  # NOQA
from cupyx.scipy.signal._signaltools import medfilt2d  # NOQA
from cupyx.scipy.signal._signaltools import lfilter  # NOQA
from cupyx.scipy.signal._signaltools import lfiltic  # NOQA
from cupyx.scipy.signal._signaltools import lfilter_zi  # NOQA
from cupyx.scipy.signal._signaltools import detrend  # NOQA
from cupyx.scipy.signal._signaltools import filtfilt  # NOQA
from cupyx.scipy.signal._signaltools import sosfilt  # NOQA
from cupyx.scipy.signal._signaltools import sosfilt_zi  # NOQA
from cupyx.scipy.signal._signaltools import sosfiltfilt  # NOQA
from cupyx.scipy.signal._signaltools import hilbert  # NOQA
from cupyx.scipy.signal._signaltools import hilbert2  # NOQA

from cupyx.scipy.signal._resample import resample  # NOQA
from cupyx.scipy.signal._resample import resample_poly  # NOQA
from cupyx.scipy.signal._resample import decimate  # NOQA

from cupyx.scipy.signal._polyutils import unique_roots  # NOQA
from cupyx.scipy.signal._polyutils import invres  # NOQA
from cupyx.scipy.signal._polyutils import invresz  # NOQA
from cupyx.scipy.signal._polyutils import residue  # NOQA
from cupyx.scipy.signal._polyutils import residuez  # NOQA

from cupyx.scipy.signal._bsplines import sepfir2d  # NOQA
from cupyx.scipy.signal._bsplines import cspline1d  # NOQA
from cupyx.scipy.signal._bsplines import qspline1d  # NOQA
from cupyx.scipy.signal._bsplines import cspline2d  # NOQA
from cupyx.scipy.signal._bsplines import qspline2d  # NOQA
from cupyx.scipy.signal._bsplines import cspline1d_eval  # NOQA
from cupyx.scipy.signal._bsplines import qspline1d_eval  # NOQA
from cupyx.scipy.signal._bsplines import spline_filter  # NOQA
from cupyx.scipy.signal._bsplines import gauss_spline  # NOQA

from cupyx.scipy.signal._splines import symiirorder1  # NOQA
from cupyx.scipy.signal._splines import symiirorder2  # NOQA

from cupyx.scipy.signal._savitzky_golay import savgol_coeffs, savgol_filter   # NOQA

from cupyx.scipy.signal._filter_design import gammatone  # NOQA
from cupyx.scipy.signal._filter_design import group_delay  # NOQA

from cupyx.scipy.signal._fir_filter_design import kaiser_atten  # NOQA
from cupyx.scipy.signal._fir_filter_design import kaiser_beta  # NOQA
from cupyx.scipy.signal._fir_filter_design import kaiserord  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import BadCoefficients  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import normalize  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import bilinear  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2lp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2hp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bs  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import bilinear_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2lp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2hp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bs_zpk  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import zpk2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import zpk2sos  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import zpk2ss   # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2sos  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2ss  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ss2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ss2zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import sos2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import sos2zpk  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import band_stop_obj  # NOQA
from cupyx.scipy.signal.windows._windows import get_window  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import buttap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb1ap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb2ap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ellipap  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import buttord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb1ord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb2ord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ellipord  # NOQA

from cupyx.scipy.signal._iir_filter_design import iirfilter  # NOQA
from cupyx.scipy.signal._iir_filter_design import butter  # NOQA
from cupyx.scipy.signal._iir_filter_design import cheby1  # NOQA
from cupyx.scipy.signal._iir_filter_design import cheby2  # NOQA
from cupyx.scipy.signal._iir_filter_design import ellip  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirdesign  # NOQA
from cupyx.scipy.signal._iir_filter_design import iircomb  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirnotch  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirpeak  # NOQA

from cupyx.scipy.signal._fir_filter_design import firwin  # NOQA
from cupyx.scipy.signal._fir_filter_design import firwin2  # NOQA
from cupyx.scipy.signal._fir_filter_design import firls  # NOQA
from cupyx.scipy.signal._fir_filter_design import minimum_phase  # NOQA

from cupyx.scipy.signal._filter_design import findfreqs  # NOQA
from cupyx.scipy.signal._filter_design import freqs  # NOQA
from cupyx.scipy.signal._filter_design import freqs_zpk  # NOQA

from cupyx.scipy.signal._filter_design import freqz  # NOQA
from cupyx.scipy.signal._filter_design import freqz_zpk  # NOQA
from cupyx.scipy.signal._filter_design import sosfreqz  # NOQA

from cupyx.scipy.signal._waveforms import chirp  # NOQA
from cupyx.scipy.signal._waveforms import gausspulse  # NOQA
from cupyx.scipy.signal._waveforms import sawtooth  # NOQA
from cupyx.scipy.signal._waveforms import square  # NOQA
from cupyx.scipy.signal._waveforms import unit_impulse  # NOQA
from cupyx.scipy.signal._max_len_seq import max_len_seq  # NOQA

from cupyx.scipy.signal._czt import *   # NOQA

from cupyx.scipy.signal._wavelets import morlet  # NOQA
from cupyx.scipy.signal._wavelets import qmf  # NOQA
from cupyx.scipy.signal._wavelets import ricker  # NOQA
from cupyx.scipy.signal._wavelets import morlet2  # NOQA
from cupyx.scipy.signal._wavelets import cwt  # NOQA

from cupyx.scipy.signal._lti_conversion import abcd_normalize   # NOQA

from cupyx.scipy.signal._upfirdn import upfirdn  # NOQA

from cupyx.scipy.signal._peak_finding import find_peaks  # NOQA
from cupyx.scipy.signal._peak_finding import peak_prominences  # NOQA
from cupyx.scipy.signal._peak_finding import peak_widths  # NOQA

from cupyx.scipy.signal._ltisys import lti  # NOQA
from cupyx.scipy.signal._ltisys import lsim  # NOQA
from cupyx.scipy.signal._ltisys import impulse  # NOQA
from cupyx.scipy.signal._ltisys import step  # NOQA
from cupyx.scipy.signal._ltisys import freqresp  # NOQA
from cupyx.scipy.signal._ltisys import bode  # NOQA

from cupyx.scipy.signal._ltisys import dlti  # NOQA
from cupyx.scipy.signal._ltisys import dlsim  # NOQA
from cupyx.scipy.signal._ltisys import dstep  # NOQA
from cupyx.scipy.signal._ltisys import dimpulse  # NOQA
from cupyx.scipy.signal._ltisys import dbode  # NOQA
from cupyx.scipy.signal._ltisys import dfreqresp  # NOQA
from cupyx.scipy.signal._ltisys import StateSpace  # NOQA
from cupyx.scipy.signal._ltisys import TransferFunction  # NOQA
from cupyx.scipy.signal._ltisys import ZerosPolesGain  # NOQA
from cupyx.scipy.signal._ltisys import cont2discrete  # NOQA
from cupyx.scipy.signal._ltisys import place_poles  # NOQA

from cupyx.scipy.signal._spectral import lombscargle  # NOQA
from cupyx.scipy.signal._spectral import periodogram  # NOQA
from cupyx.scipy.signal._spectral import welch  # NOQA
from cupyx.scipy.signal._spectral import csd  # NOQA
from cupyx.scipy.signal._spectral import check_COLA  # NOQA
from cupyx.scipy.signal._spectral import check_NOLA  # NOQA
from cupyx.scipy.signal._spectral import stft  # NOQA
from cupyx.scipy.signal._spectral import istft  # NOQA
from cupyx.scipy.signal._spectral import spectrogram  # NOQA
from cupyx.scipy.signal._spectral import vectorstrength  # NOQA
from cupyx.scipy.signal._spectral import coherence  # NOQA

from cupyx.scipy.signal._peak_finding import argrelextrema  # NOQA
from cupyx.scipy.signal._peak_finding import argrelmin  # NOQA
from cupyx.scipy.signal._peak_finding import argrelmax  # NOQA

==> python-cupy-14.0.1-2-x86_64.pkg.tar.zst: usr/lib/python3.14/site-packages/cupyx/scipy/signal/__init__.py <==
from cupyx.scipy.signal._signaltools import convolve  # NOQA
from cupyx.scipy.signal._signaltools import correlate  # NOQA
from cupyx.scipy.signal._signaltools import deconvolve  # NOQA
from cupyx.scipy.signal._signaltools import fftconvolve  # NOQA
from cupyx.scipy.signal._signaltools import choose_conv_method  # NOQA
from cupyx.scipy.signal._signaltools import oaconvolve  # NOQA
from cupyx.scipy.signal._signaltools import convolve2d  # NOQA
from cupyx.scipy.signal._signaltools import correlate2d  # NOQA
from cupyx.scipy.signal._signaltools import correlation_lags  # NOQA
from cupyx.scipy.signal._signaltools import wiener  # NOQA
from cupyx.scipy.signal._signaltools import order_filter  # NOQA
from cupyx.scipy.signal._signaltools import medfilt  # NOQA
from cupyx.scipy.signal._signaltools import medfilt2d  # NOQA
from cupyx.scipy.signal._signaltools import lfilter  # NOQA
from cupyx.scipy.signal._signaltools import lfiltic  # NOQA
from cupyx.scipy.signal._signaltools import lfilter_zi  # NOQA
from cupyx.scipy.signal._signaltools import detrend  # NOQA
from cupyx.scipy.signal._signaltools import filtfilt  # NOQA
from cupyx.scipy.signal._signaltools import sosfilt  # NOQA
from cupyx.scipy.signal._signaltools import sosfilt_zi  # NOQA
from cupyx.scipy.signal._signaltools import sosfiltfilt  # NOQA
from cupyx.scipy.signal._signaltools import hilbert  # NOQA
from cupyx.scipy.signal._signaltools import hilbert2  # NOQA

from cupyx.scipy.signal._resample import resample  # NOQA
from cupyx.scipy.signal._resample import resample_poly  # NOQA
from cupyx.scipy.signal._resample import decimate  # NOQA

from cupyx.scipy.signal._polyutils import unique_roots  # NOQA
from cupyx.scipy.signal._polyutils import invres  # NOQA
from cupyx.scipy.signal._polyutils import invresz  # NOQA
from cupyx.scipy.signal._polyutils import residue  # NOQA
from cupyx.scipy.signal._polyutils import residuez  # NOQA

from cupyx.scipy.signal._bsplines import sepfir2d  # NOQA
from cupyx.scipy.signal._bsplines import cspline1d  # NOQA
from cupyx.scipy.signal._bsplines import qspline1d  # NOQA
from cupyx.scipy.signal._bsplines import cspline2d  # NOQA
from cupyx.scipy.signal._bsplines import qspline2d  # NOQA
from cupyx.scipy.signal._bsplines import cspline1d_eval  # NOQA
from cupyx.scipy.signal._bsplines import qspline1d_eval  # NOQA
from cupyx.scipy.signal._bsplines import spline_filter  # NOQA
from cupyx.scipy.signal._bsplines import gauss_spline  # NOQA

from cupyx.scipy.signal._splines import symiirorder1  # NOQA
from cupyx.scipy.signal._splines import symiirorder2  # NOQA

from cupyx.scipy.signal._savitzky_golay import savgol_coeffs, savgol_filter   # NOQA

from cupyx.scipy.signal._filter_design import gammatone  # NOQA
from cupyx.scipy.signal._filter_design import group_delay  # NOQA

from cupyx.scipy.signal._fir_filter_design import kaiser_atten  # NOQA
from cupyx.scipy.signal._fir_filter_design import kaiser_beta  # NOQA
from cupyx.scipy.signal._fir_filter_design import kaiserord  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import BadCoefficients  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import normalize  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import bilinear  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2lp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2hp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bp  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bs  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import bilinear_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2lp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2hp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bp_zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import lp2bs_zpk  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import zpk2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import zpk2sos  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import zpk2ss   # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2sos  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import tf2ss  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ss2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ss2zpk  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import sos2tf  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import sos2zpk  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import band_stop_obj  # NOQA
from cupyx.scipy.signal.windows._windows import get_window  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import buttap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb1ap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb2ap  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ellipap  # NOQA

from cupyx.scipy.signal._iir_filter_conversions import buttord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb1ord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import cheb2ord  # NOQA
from cupyx.scipy.signal._iir_filter_conversions import ellipord  # NOQA

from cupyx.scipy.signal._iir_filter_design import iirfilter  # NOQA
from cupyx.scipy.signal._iir_filter_design import butter  # NOQA
from cupyx.scipy.signal._iir_filter_design import cheby1  # NOQA
from cupyx.scipy.signal._iir_filter_design import cheby2  # NOQA
from cupyx.scipy.signal._iir_filter_design import ellip  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirdesign  # NOQA
from cupyx.scipy.signal._iir_filter_design import iircomb  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirnotch  # NOQA
from cupyx.scipy.signal._iir_filter_design import iirpeak  # NOQA

from cupyx.scipy.signal._fir_filter_design import firwin  # NOQA
from cupyx.scipy.signal._fir_filter_design import firwin2  # NOQA
from cupyx.scipy.signal._fir_filter_design import firls  # NOQA
from cupyx.scipy.signal._fir_filter_design import minimum_phase  # NOQA

from cupyx.scipy.signal._filter_design import findfreqs  # NOQA
from cupyx.scipy.signal._filter_design import freqs  # NOQA
from cupyx.scipy.signal._filter_design import freqs_zpk  # NOQA

from cupyx.scipy.signal._filter_design import freqz  # NOQA
from cupyx.scipy.signal._filter_design import freqz_zpk  # NOQA
from cupyx.scipy.signal._filter_design import freqz_sos  # NOQA
from cupyx.scipy.signal._filter_design import sosfreqz  # NOQA

from cupyx.scipy.signal._waveforms import chirp  # NOQA
from cupyx.scipy.signal._waveforms import gausspulse  # NOQA
from cupyx.scipy.signal._waveforms import sawtooth  # NOQA
from cupyx.scipy.signal._waveforms import square  # NOQA
from cupyx.scipy.signal._waveforms import unit_impulse  # NOQA
from cupyx.scipy.signal._waveforms import sweep_poly  # NOQA
from cupyx.scipy.signal._max_len_seq import max_len_seq  # NOQA

from cupyx.scipy.signal._czt import *   # NOQA

from cupyx.scipy.signal._wavelets import morlet  # NOQA
from cupyx.scipy.signal._wavelets import qmf  # NOQA
from cupyx.scipy.signal._wavelets import ricker  # NOQA
from cupyx.scipy.signal._wavelets import morlet2  # NOQA
from cupyx.scipy.signal._wavelets import cwt  # NOQA

from cupyx.scipy.signal._lti_conversion import abcd_normalize   # NOQA

from cupyx.scipy.signal._upfirdn import upfirdn  # NOQA

from cupyx.scipy.signal._peak_finding import find_peaks  # NOQA
from cupyx.scipy.signal._peak_finding import peak_prominences  # NOQA
from cupyx.scipy.signal._peak_finding import peak_widths  # NOQA

from cupyx.scipy.signal._ltisys import lti  # NOQA
from cupyx.scipy.signal._ltisys import lsim  # NOQA
from cupyx.scipy.signal._ltisys import impulse  # NOQA
from cupyx.scipy.signal._ltisys import step  # NOQA
from cupyx.scipy.signal._ltisys import freqresp  # NOQA
from cupyx.scipy.signal._ltisys import bode  # NOQA

from cupyx.scipy.signal._ltisys import dlti  # NOQA
from cupyx.scipy.signal._ltisys import dlsim  # NOQA
from cupyx.scipy.signal._ltisys import dstep  # NOQA
from cupyx.scipy.signal._ltisys import dimpulse  # NOQA
from cupyx.scipy.signal._ltisys import dbode  # NOQA
from cupyx.scipy.signal._ltisys import dfreqresp  # NOQA
from cupyx.scipy.signal._ltisys import StateSpace  # NOQA
from cupyx.scipy.signal._ltisys import TransferFunction  # NOQA
from cupyx.scipy.signal._ltisys import ZerosPolesGain  # NOQA
from cupyx.scipy.signal._ltisys import cont2discrete  # NOQA
from cupyx.scipy.signal._ltisys import place_poles  # NOQA

from cupyx.scipy.signal._spectral import lombscargle  # NOQA
from cupyx.scipy.signal._spectral import periodogram  # NOQA
from cupyx.scipy.signal._spectral import welch  # NOQA
from cupyx.scipy.signal._spectral import csd  # NOQA
from cupyx.scipy.signal._spectral import check_COLA  # NOQA
from cupyx.scipy.signal._spectral import check_NOLA  # NOQA
from cupyx.scipy.signal._spectral import stft  # NOQA
from cupyx.scipy.signal._spectral import istft  # NOQA
from cupyx.scipy.signal._spectral import spectrogram  # NOQA
from cupyx.scipy.signal._spectral import vectorstrength  # NOQA
from cupyx.scipy.signal._spectral import coherence  # NOQA

from cupyx.scipy.signal._peak_finding import argrelextrema  # NOQA
from cupyx.scipy.signal._peak_finding import argrelmin  # NOQA
from cupyx.scipy.signal._peak_finding import argrelmax  # NOQA
